@@ -1,9 +1,16 @@
 import re
+import os
 
 
 def skip_warning(warning):
     # XXX quick dirty hack, just need to keep the line in the warning
-    line = open(warning.filename).readlines()[warning.lineno - 1]
+    if not os.path.isfile(warning.filename):
+        return False
+
+    # XXX should cache the file in memory
+    with open(warning.filename) as f:
+        line = f.readlines()[warning.lineno - 1]
+
     return skip_line(line)
 
 
